#
# spec file for package rttr
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rttr
Version:        0.9.6
Release:        5.5
Summary:        Run Time Type Reflection for C++
License:        MIT
Group:          Development/Languages/C and C++
URL:            http://www.rttr.org/releases/rttr-%{version}-src.tar.gz
Source0:        %{name}-%{version}-src.tar.gz
#PATCH-FIX-OPENSUSE cxx11_compiler_flags.patch force c++11 mode on gcc4.8 (for Leap 42.3)
Patch0:         cxx11_compiler_flags.patch
#PATCH-FIX-OPENSUSE cmake_install_dir.patch fix cmake installation directories for SUSE standards
Patch1:         cmake_install_dir.patch
#PATCH-FIX-OPENSUSE doxygen_remove_date_time.patch remove date and time information from generated documentation
Patch2:         doxygen_remove_date_time.patch
#PATCH-FIX-OPENSUSE skip_json_example.patch fix compile error (https://github.com/rttrorg/rttr/issues/224)
Patch3:         skip_json_example.patch
# PATCH-FIX-OPENSUSE fix-include-permissions.patch fix wrong permissions of headers (https://github.com/rttrorg/rttr/issues/147)
Patch4:         fix-include-permissions.patch
# PATCH-FIX-UPSTREAM lp64.patch Support all LP64 architectures (https://github.com/rttrorg/rttr/pull/231)
Patch5:         lp64.patch
#PATCH-FIX-UPSTREAM remove_pessimizing_moves.patch remove pessimizing move calls (https://github.com/rttrorg/rttr/pull/243)
Patch6:         remove_pessimizing_moves.patch
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  doxygen
BuildRequires:  gcc-c++

%description
Run Time Type Reflection is the the ability of a computer program to
introspect and modify objects at runtime. It is also the name of the
library itself, which is written in C++.

%prep
%setup -q -n%{name}-%{version}
%if 0%{?suse_version} < 1500
%patch -P 0 -p1
%endif
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1

#only apply move elision to gcc versions that support it
%if 0%{?suse_version} >= 1500
%patch -P 6 -p1
%endif

%build
find . -type f -exec chmod a-x "{}" +
dos2unix README.md
%cmake -DBUILD_BENCHMARKS=OFF -DCMAKE_INSTALL_CMAKEDIR=cmake -DBUILD_UNIT_TESTS=OFF
#make unit tests pass
export LD_LIBRARY_PATH=%{_builddir}/rttr-%{version}/build/lib/
%make_jobs

%install
#make unit tests pass
export LD_LIBRARY_PATH=%{_builddir}/rttr-%{version}/build/lib/
%cmake_install rttr_core
rm -Rf %{buildroot}/%{_datadir}/rttr

%package -n lib%{name}_core0_9_6
Summary:        Run Time Type Reflection for C++
Group:          System/Libraries

%description -n lib%{name}_core0_9_6
Run Time Type Reflection is the the ability of a computer program to
introspect and modify objects at runtime. It is also the name of the
library itself, which is written in C++.

%post -n lib%{name}_core0_9_6 -p /sbin/ldconfig
%postun -n lib%{name}_core0_9_6 -p /sbin/ldconfig

%files -n lib%{name}_core0_9_6
%license LICENSE.txt
%{_libdir}/librttr_core.so.%{version}

%package  devel
Summary:        Header files for the C++ Run Time Type Reflection library
Group:          Development/Languages/C and C++
Requires:       librttr_core0_9_6 = %{version}

%description  devel
Run Time Type Reflection is the the ability of a computer program to
introspect and modify objects at runtime. It is also the name of the
library itself, which is written in C++.

%files devel
%{_includedir}/rttr/
%{_libdir}/librttr_core.so
%{_libdir}/cmake/rttr/

%package devel-doc
Summary:        Documentation for rttr
Group:          Documentation/Other

%description devel-doc
API Documentation for rttr

%files devel-doc
%doc README.md
%{_docdir}/rttr/

%changelog
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Jun 27 2019 Luca Beltrame <lbeltrame@kde.org>
- Disable tests to allow the package to build under GCC 9
* Tue Jun  4 2019 Dan Weatherill <plasteredparrot@gmail.com>
- remove_pessimizing_moves.patch: remove NRVO pessimizing moves
  (fixes a warning on gcc 9 to fix current Factory build)
* Wed May  8 2019 Andreas Schwab <schwab@suse.de>
- lp64.patch: Support all LP64 architectures
* Fri Mar 29 2019 Luca Beltrame <lbeltrame@kde.org>
- Add patch to fix wrong permissions of headers (only readable
  by root once installed; gh#rttrorg/rttr#147):
  * fix-include-permissions.patch
* Fri Mar 15 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix build (gh#rttrorg/rttr#224):
  * skip_json_example.patch
- Clean spec a bit
* Wed Jan 16 2019 Jan Engelhardt <jengelh@inai.de>
- Fix RPM groups, trim filler wording from descriptions.
* Thu Jun 21 2018 dan.weatherill@cantab.net
- fix incorrect permissions in -devel package installed files
* Tue Jun 19 2018 dan.weatherill@cantab.net
- update package to new version (0.9.6)
- update patch for buildsystem installation locations
- patch for forcing c++11 mode on gcc4.8 (for openSUSE_Leap_42.3)
* Thu Jul 27 2017 dan.weatherill@cantab.net
- initial package from upstream source (0.9.5)
- patch for correcting buildsystem installation locations
